@@ -7,6 +7,8 @@ pyautogui.FAILSAFE = False
 class Mouse(object):
     def __init__(self):
         super()
+        self.x = 0
+        self.y = 0
 
     def mouseClick(self,
                    count, Time=1, isdoubleclick=True, x=None, y=None, button='left', istripleClick=False):
@@ -23,10 +25,8 @@ class Mouse(object):
             time.sleep(Time)
 
     def getMouseXY(self):
-        try:
-            return pyautogui.position()
-        except Exception as e:
-            print(repr(e))
+        self.x, self.y = pyautogui.position()
+        return self.x, self.y
 
     def MoveTo(self, x, y, duration=0.25):
         pyautogui.moveTo(x=x, y=y, duration=duration)
@@ -35,18 +35,41 @@ class Mouse(object):
         pyautogui.dragTo(x, y, duration=duration, button=button)
 
 
-def prees(key, count, Time=1, ishotkey=False, isprees=True, iskeyUp=False, iskeyDown=False, istypewrite=False):
-    c = 0
-    while c < count:
-        if isprees:
+class keyboard(object):
+    def __init__(self):
+        super()
+
+    def hotkey(*args, count, Time=1):
+        c = 0
+        while c < count:
+            pyautogui.hotkey(args)
+            c += 1
+            time.sleep(Time)
+
+    def press(key, count, Time=1):
+        c = 0
+        while c < count:
             pyautogui.press(key)
-        elif ishotkey:
-            pyautogui.hotkey(key)
-        elif iskeyUp:
+            c += 1
+            time.sleep(Time)
+
+    def keyUp(key, count, Time=1):
+        c = 0
+        while c < count:
             pyautogui.keyUp(key)
-        elif iskeyDown:
+            c += 1
+            time.sleep(Time)
+
+    def keyDown(key, count, Time=1):
+        c = 0
+        while c < count:
             pyautogui.keyDown(key)
-        elif istypewrite:
+            c += 1
+            time.sleep(Time)
+
+    def typewrite(key, count, Time=1):
+        c = 0
+        while c < count:
             pyautogui.typewrite(key)
-        time.sleep(Time)
-        c += 1
+            c += 1
+            time.sleep(Time)
